@@ -100,6 +100,9 @@ impl MenuItemAttributes {
   pub fn id(self) -> MenuId {
     MenuId::EMPTY
   }
+  pub fn title(&self) -> String {
+    "".to_owned()
+  }
   pub fn set_enabled(&mut self, _is_enabled: bool) {}
   pub fn set_title(&mut self, _title: &str) {}
   pub fn set_selected(&mut self, _is_selected: bool) {}
