@@ -209,10 +209,10 @@ impl<T: 'static> EventLoop<T> {
             }
           }
           WindowRequest::DragWindow => {
-            let display = window.display();
-            if let Some(cursor) = display
+            if let Some(cursor) = window
+              .display()
               .default_seat()
-              .and_then(|device_manager| device_manager.pointer())
+              .and_then(|seat| seat.pointer())
             {
               let (_, x, y) = cursor.position();
               window.begin_move_drag(1, x, y, 0);
@@ -298,6 +298,17 @@ impl<T: 'static> EventLoop<T> {
               }
             };
           }
+          WindowRequest::CursorPosition((x, y)) => {
+            if let Some(cursor) = window
+              .display()
+              .default_seat()
+              .and_then(|seat| seat.pointer())
+            {
+              if let Some(screen) = window.screen() {
+                cursor.warp(&screen, x, y);
+              }
+            }
+          }
           WindowRequest::WireUpEvents => {
             window.add_events(
               EventMask::POINTER_MOTION_MASK
