@@ -78,6 +78,13 @@ impl MenuItemAttributes {
   pub fn id(self) -> MenuId {
     self.id
   }
+  pub fn title(&self) -> String {
+    self
+      .gtk_item
+      .label()
+      .map(|gstr| gstr.as_str().to_owned())
+      .unwrap_or("".to_owned())
+  }
   pub fn set_enabled(&mut self, is_enabled: bool) {
     self.gtk_item.set_sensitive(is_enabled);
   }
