@@ -21,7 +21,9 @@ use crate::{
   window::WindowId,
 };
 
-use super::{app_state::AppState, event::EventWrapper, window::get_window_id};
+use super::{
+  app_state::AppState, event::EventWrapper, util::ns_string_to_rust, window::get_window_id,
+};
 
 static BLOCK_PTR: &str = "taoMenuItemBlockPtr";
 
@@ -45,6 +47,12 @@ impl MenuItemAttributes {
     // can be used to compare
     MenuId::EMPTY
   }
+  pub fn title(&self) -> String {
+    unsafe {
+      let title: id = msg_send![self.1, title];
+      ns_string_to_rust(title)
+    }
+  }
 
   pub fn set_enabled(&mut self, is_enabled: bool) {
     unsafe {
